
with Types, Failure, Inertia, Clock, State, Steer;
use  Types;

separate(Main)
procedure Control 
is 
   Displacement     : Vector;
   Displacement_Ang : Angle;
   To_Target        : Vector;
begin
   
   -- sum of displacement in the X and Y direction, respectively.
   -- (displacement (scalar: distance)     is the integral of
   --  velocity     (scalar: speed), which is the integral of
   --  acceleration (scalar: quickening),
   --  hence the double-integral.)
   
   Displacement := ( X => Integral ( Integral ( Inertia.X_Acceleration_Mag , Clock.T ) , Clock.T ) , 
                     Y => Integral ( Integral ( Inertia.Y_Acceleration_Mag , Clock.T ) , Clock.T ) );
   
   -- update location
   State.Location := Vector_Add (State.Location, Displacement);
   
   -- remaining displacement to target
   -- (Location + To_Target = Target).
   
   To_Target      := Vector_Sub ( Target , State.Location );
   
   -- angular displacement
   -- (yaw; distance, in radians, that the missile has rotated).
   Displacement_Ang :=    Integral ( Integral ( Inertia.Z_Acceleration_Ang , Clock.T ) , Clock.T );
   
   -- check self-destruct condition.
   State.Destruct := Failure.F;
   
   -- check detonation condition.
   State.Detonate := (Vector_Mag (To_Target) <= Threshold);
   
   -- set up Steer for actuation.
   Steer.Orientation := Steer.Orientation + Displacement_Ang;
   Steer.Target_Dir  := Vector_Ang (To_Target);
   
end Control;
